summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWes Haggard <weshaggard@users.noreply.github.com>2018-10-16 16:41:42 -0700
committerGitHub <noreply@github.com>2018-10-16 16:41:42 -0700
commit116461030e106f14d7fc53a2143930db21d6eaa6 (patch)
tree4828c62c13fca1cf3f8f4e876de9d8e0dbe4c799
parent3e7950e9425106ccfaadbaa96710ccc6dea7d886 (diff)
downloadcoreclr-116461030e106f14d7fc53a2143930db21d6eaa6.tar.gz
coreclr-116461030e106f14d7fc53a2143930db21d6eaa6.tar.bz2
coreclr-116461030e106f14d7fc53a2143930db21d6eaa6.zip
Update command lines for building corefx repo (#20415)
* Update command lines for building corefx repo * Combine build-managed and build-native to avoid some init issues cross and portable parameters correctly default for native builds
-rw-r--r--tests/scripts/run-corefx-tests.py60
1 files changed, 11 insertions, 49 deletions
diff --git a/tests/scripts/run-corefx-tests.py b/tests/scripts/run-corefx-tests.py
index a569aadd4c..a710d909c0 100644
--- a/tests/scripts/run-corefx-tests.py
+++ b/tests/scripts/run-corefx-tests.py
@@ -235,7 +235,7 @@ def main(args):
while True:
res = subprocess.check_output(['tasklist'])
if not 'VBCSCompiler.exe' in res:
- break
+ break
os.chdir(fx_root)
os.system('git clean -fxd')
os.chdir(clr_root)
@@ -285,50 +285,12 @@ def main(args):
os.makedirs(fx_home)
os.putenv('HOME', fx_home)
log('HOME=' + fx_home)
-
- # Gather up some arguments to pass to build-managed, build-native, and build-tests scripts.
-
- config_args = '-Release -os:%s -buildArch:%s' % (clr_os, arch)
-
- # Run the primary (non-test) corefx build. We previously passed the argument:
- #
- # /p:CoreCLROverridePath=<path-to-core_root>
- #
- # which causes the corefx build to overwrite its built runtime with the binaries from
- # the coreclr build. However, this often causes build failures when breaking changes are
- # in progress (e.g., a breaking change is made in coreclr that has not yet had compensating
- # changes made in the corefx repo). Instead, build corefx normally. This should always work
- # since corefx is protected by a CI testing system. Then, overwrite the built corefx
- # runtime with the runtime built in the coreclr build. The result will be that perhaps
- # some, hopefully few, corefx tests will fail, but the builds will never fail.
-
- # Cross build corefx for arm64 on x64.
- # Cross build corefx for arm32 on x86.
-
- build_native_args = ''
-
- if not Is_windows and arch == 'arm' :
- # We need to force clang5.0; we are building in a docker container that doesn't have
- # clang3.9, which is currently the default used by build-native.sh. We need to pass
- # "-cross", but we also pass "-portable", which build-native.sh normally passes
- # (there doesn't appear to be a way to pass these individually).
- build_native_args += ' -AdditionalArgs:"-portable -cross" -Clang:clang5.0'
-
- if not Is_windows and arch == 'arm64' :
- # We need to pass "-cross", but we also pass "-portable", which build-native.sh normally
- # passes (there doesn't appear to be a way to pass these individually).
- build_native_args += ' -AdditionalArgs:"-portable -cross"'
-
- command = ' '.join(('build-native.cmd' if Is_windows else './build-native.sh',
- config_args,
- build_native_args))
- log(command)
- returncode = 0 if testing else os.system(command)
- if returncode != 0:
- log('Error: exit code %s' % returncode)
- sys.exit(1)
- command = ' '.join(('build-managed.cmd' if Is_windows else './build-managed.sh', config_args))
+ # Gather up some arguments to pass to the different build scripts.
+
+ config_args = '-Release /p:OSGroup=%s /p:ArchGroup=%s' % (clr_os, arch)
+
+ command = ' '.join(('build.cmd' if Is_windows else './build.sh', config_args))
log(command)
returncode = 0 if testing else os.system(command)
if returncode != 0:
@@ -353,12 +315,12 @@ def main(args):
log('Updating CoreCLR: %s => %s' % (core_root, fx_runtime))
copy_files(core_root, fx_runtime)
# Build the build-tests command line.
if Is_windows:
- command = 'build-tests.cmd'
+ command = 'build.cmd -test'
else:
- command = './build-tests.sh'
+ command = './build.sh -test'
# If we're doing altjit testing, then don't run any tests that don't work with altjit.
if ci_arch is not None and (ci_arch == 'x86_arm_altjit' or ci_arch == 'x64_arm64_altjit'):
@@ -380,13 +342,13 @@ def main(args):
without_categories_string = '/p:WithoutCategories="IgnoreForCI;XsltcExeRequired"'
with open(without_categories_filename, "w") as without_categories_file:
without_categories_file.write(without_categories_string)
- without_categories = "-- @%s" % without_categories_filename
+ without_categories = " @%s" % without_categories_filename
log('Response file %s contents:' % without_categories_filename)
log('%s' % without_categories_string)
log('[end response file contents]')
else:
- without_categories = '-- /p:WithoutCategories=IgnoreForCI'
+ without_categories = ' /p:WithoutCategories=IgnoreForCI'
command = ' '.join((
command,
@@ -353,12 +315,12 @@ def main(args):
log('Updating CoreCLR: %s => %s' % (core_root, fx_runtime))
copy_files(core_root, fx_runtime)
- # Build the build-tests command line.
+ # Build the test command line.
if Is_windows: